<?php
/**
 * Kenta Theme Customizer
 *
 * @package Kenta
 */

use LottaFramework\Customizer\CallToActionSection;
use LottaFramework\Facades\Css;
use LottaFramework\Facades\CZ;

// customizer traits
require get_template_directory() . '/inc/traits/trait-button-controls.php';
require get_template_directory() . '/inc/traits/trait-post-structure.php';
require get_template_directory() . '/inc/traits/trait-post-card.php';
require get_template_directory() . '/inc/traits/trait-article-controls.php';
require get_template_directory() . '/inc/traits/trait-icon-button-controls.php';
require get_template_directory() . '/inc/traits/trait-widgets-controls.php';
require get_template_directory() . '/inc/traits/trait-global-color-controls.php';

// customizer elements
require get_template_directory() . '/inc/elements/class-button-element.php';
require get_template_directory() . '/inc/elements/class-logo-element.php';
require get_template_directory() . '/inc/elements/class-menu-element.php';
require get_template_directory() . '/inc/elements/class-collapsable-menu-element.php';
require get_template_directory() . '/inc/elements/class-trigger-element.php';
require get_template_directory() . '/inc/elements/class-copyright-element.php';
require get_template_directory() . '/inc/elements/class-search-element.php';
require get_template_directory() . '/inc/elements/class-cart-element.php';
require get_template_directory() . '/inc/elements/class-widgets-element.php';

// customizer builder
require get_template_directory() . '/inc/builder/class-builder-column.php';
require get_template_directory() . '/inc/builder/class-modal-row.php';
require get_template_directory() . '/inc/builder/class-header-column.php';
require get_template_directory() . '/inc/builder/class-header-row.php';
require get_template_directory() . '/inc/builder/class-header-builder.php';
require get_template_directory() . '/inc/builder/class-footer-column.php';
require get_template_directory() . '/inc/builder/class-footer-row.php';
require get_template_directory() . '/inc/builder/class-footer-builder.php';

// customizer sections
require get_template_directory() . '/inc/customizer/class-header-section.php';
require get_template_directory() . '/inc/customizer/class-footer-section.php';
require get_template_directory() . '/inc/customizer/class-colors-section.php';
require get_template_directory() . '/inc/customizer/class-global-section.php';
require get_template_directory() . '/inc/customizer/class-archive-section.php';
require get_template_directory() . '/inc/customizer/class-content-section.php';
require get_template_directory() . '/inc/customizer/class-single-post-section.php';
require get_template_directory() . '/inc/customizer/class-pages-section.php';
require get_template_directory() . '/inc/customizer/class-store-catalog-section.php';
require get_template_directory() . '/inc/customizer/class-store-notice-section.php';
require get_template_directory() . '/inc/customizer/class-placeholders.php';

/**
 * Theme customizer register
 *
 * @param WP_Customize_Manager|null $wp_customize Theme Customizer object.
 */
function kenta_customize_register( $wp_customize ) {
	if ( ! $wp_customize instanceof WP_Customize_Manager ) {
		$wp_customize = null;
	} else {

		$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

		if ( isset( $wp_customize->selective_refresh ) ) {
			$wp_customize->selective_refresh->add_partial(
				'blogname',
				array(
					'selector'        => '.site-title a',
					'render_callback' => function () {
						echo esc_html( get_bloginfo( 'name' ) );
					},
				)
			);
			$wp_customize->selective_refresh->add_partial(
				'blogdescription',
				array(
					'selector'        => '.site-tagline',
					'render_callback' => function () {
						echo esc_html( get_bloginfo( 'description' ) );
					},
				)
			);
		}
	}

	Kenta_Placeholders::instance();

	if ( $wp_customize ) {
		if ( ! KENTA_CMP_ACTIVE ) {
			$wp_customize->add_section( new CallToActionSection( $wp_customize, 'kenta_install_companion', array(
				'priority' => 0,
				'title'    => __( 'Install Companion Plugin', 'kenta' ),
				'link'     => array(
					'url' => esc_url( add_query_arg( array( 'action' => 'kenta_install_companion' ), admin_url( 'admin.php' ) ) ),
				),
				'desc'     => kenta_why_companion_link()
			) ) );
		} else if ( ! KENTA_CMP_PRO_ACTIVE ) {
			$wp_customize->add_section( new CallToActionSection( $wp_customize, 'kenta_upgrade', array(
				'priority' => 0,
				'title'    => __( 'Upgrade To Pro', 'kenta' ),
				'link'     => array(
					'url'    => kenta_upsell_url(),
					'target' => '_blank',
				),
				'desc'     => kenta_pro_features_link()
			) ) );
		}
	}

	CZ::addSection( $wp_customize, new Kenta_Header_Section( 'kenta_header', __( 'Header Builder', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Footer_Section( 'kenta_footer', __( 'Footer Builder', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Colors_Section( 'kenta_colors', __( 'Colors', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Global_Section( 'kenta_global', __( 'Global', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Archive_Section( 'kenta_archive', __( 'Archive Settings', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Content_Section( 'kenta_content', __( 'Content Settings', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Single_Post_Section( 'kenta_single_post', __( 'Single Post Settings', 'kenta' ) ) );
	CZ::addSection( $wp_customize, new Kenta_Pages_Section( 'kenta_pages', __( 'Pages Settings', 'kenta' ) ) );

	if ( KENTA_WOOCOMMERCE_ACTIVE ) {
		if ( $wp_customize ) {
			CZ::changeObject( $wp_customize, 'panel', 'woocommerce', 'priority', 20 );
			// Remove default catalog columns
			$wp_customize->remove_control( 'woocommerce_catalog_columns' );
		}

		CZ::addSection( $wp_customize, new Kenta_Store_Notice_Section( 'woocommerce_store_notice', __( 'Store Notice', 'kenta' ), 0, 'woocommerce' ) );
		CZ::addSection( $wp_customize, new Kenta_Store_Catalog_Section( 'woocommerce_product_catalog', __( 'Product Catalog', 'kenta' ), 0, 'woocommerce' ) );
	}
}

add_action( 'customize_register', 'kenta_customize_register' );
add_action( 'kenta_after_lotta_framework_bootstrap', 'kenta_customize_register' );

if ( ! function_exists( 'kenta_customizer_scripts' ) ) {
	/**
	 * Enqueue customizer scripts
	 */
	function kenta_customizer_scripts() {
		kenta_enqueue_global_vars( true );
	}
}
add_action( 'customize_controls_enqueue_scripts', 'kenta_customizer_scripts' );

/**
 * Change customizer localize object
 *
 * @param $localize
 *
 * @return mixed
 */
function kenta_customizer_localize( $localize ) {
	$localize['customizer']['colorPicker']['swatches'] = [
		'var(--kenta-primary-color)',
		'var(--kenta-primary-active)',
		'var(--kenta-accent-color)',
		'var(--kenta-accent-active)',
		'var(--kenta-base-300)',
		'var(--kenta-base-200)',
		'var(--kenta-base-100)',
		'var(--kenta-base-color)',
		Css::INITIAL_VALUE,
	];

	return $localize;
}

add_filter( 'lotta_filter_customizer_js_localize', 'kenta_customizer_localize' );
